#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pysegmenters_blingfire']

package_data = \
{'': ['*']}

package_dir = \
{'': 'src'}

install_requires = \
['pymultirole-plugins>=0.5.0,<0.6.0', 'numpy', 'blingfire']

extras_require = \
{'dev': ['flit', 'pre-commit', 'bump2version'],
 'docs': ['sphinx',
          'sphinx-rtd-theme',
          'm2r2',
          'sphinxcontrib.apidoc',
          'jupyter_sphinx'],
 'test': ['pytest', 'pytest-cov', 'pytest-flake8', 'pytest-black', 'tox']}

entry_points = \
{'pysegmenters.plugins': ['blingfire = '
                          'pysegmenters_blingfire.blingfire:BlingFireSegmenter']}

setup(name='pysegmenters-blingfire',
      version='0.5.31',
      description='Segmenter based on Spacy',
      author='Olivier Terrier',
      author_email='olivier.terrier@kairntech.com',
      url='https://github.com/oterrier/pysegmenters_blingfire/',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.8',
     )
